# NECTAR_MSI: NoisE CorrecTion AlgoRithm for mass-spectrometry-imaging

NECTAR is a Python package for noise correction and noise determination in mass-spectrometry-imaging (MSI) data. 
This package is explained in detail in: (reference to the paper) and it is shown here for transparency purposes. 
Please cite this paper (citation) if you use this package.

The folder "example data" contains the mean spectrum of the tissue area correspondent to the MALDI data analised in the paper. This spectrum can be used to test some of the features described on the paper. Due to the big size of the MSI data, the .imzML file could be provided under request to the authors. 

You can use your own .imzML file to obtain a de-noised list of peaks of interest. The script can be run from the Jupyter notebook provided, or from the main.py file.

# Installation
pip install nectar-msi

# License
nectar is free software licensed under the GNU Public License (v3).

# Aknowledgments
This work was supported by Cancer Research UK [C58393/A24034] and the UK’s National Measurement System programs.


